abacusai.streaming_row_count — AbacusAI documentation

# `abacusai.streaming_row_count`

## Module Contents

### Classes

`StreamingRowCount` | Returns the number of rows in a streaming feature group from the specified time

class abacusai.streaming_row_count.StreamingRowCount(client, count=None, startTsMs=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Returns the number of rows in a streaming feature group from the specified time

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - count (int) – The number of rows in the feature group

    - startTsMs (int) – The start time for the number of rows.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict